import astro
import pytest


@pytest.mark.flaky(max_runs=2)
class TestVisionClassify:
    def test_ny(self):
        img = astro.beta.Image(
            "https://images.unsplash.com/photo-1568515387631-8b650bbcdb90"
        )
        result = astro.beta.classify(img, labels=["urban", "rural"])
        assert result == "urban"

    def test_ny_images_input(self):
        img = astro.beta.Image(
            "https://images.unsplash.com/photo-1568515387631-8b650bbcdb90"
        )
        result = astro.beta.classify(
            data=None, images=[img], labels=["urban", "rural"]
        )
        assert result == "urban"

    def test_ny_image_input(self):
        img = astro.beta.Image(
            "https://images.unsplash.com/photo-1568515387631-8b650bbcdb90"
        )
        result = astro.beta.classify(data=img, labels=["urban", "rural"])
        assert result == "urban"

    def test_ny_image_and_text(self):
        img = astro.beta.Image(
            "https://images.unsplash.com/photo-1568515387631-8b650bbcdb90"
        )
        result = astro.beta.classify(
            data="I see the empire state building",
            images=[img],
            labels=["urban", "rural"],
        )
        assert result == "urban"

    def test_classify_dog(self):
        img = astro.beta.Image(
            "https://upload.wikimedia.org/wikipedia/commons/9/99/Brooks_Chase_Ranger_of_Jolly_Dogs_Jack_Russell.jpg"
        )
        result = astro.beta.classify(
            img,
            labels=["cat", "dog", "horse"],
        )
        assert result == "dog"

    def test_classify_dog_color(self):
        img = astro.beta.Image(
            "https://upload.wikimedia.org/wikipedia/commons/9/99/Brooks_Chase_Ranger_of_Jolly_Dogs_Jack_Russell.jpg"
        )
        result = astro.beta.classify(
            img,
            labels=["brown", "black", "blonde", "white", "gray", "golden", "red"],
            instructions="the color of the dog",
        )
        assert result == "white"

    def test_classify_background_color(self):
        img = astro.beta.Image(
            "https://upload.wikimedia.org/wikipedia/commons/9/99/Brooks_Chase_Ranger_of_Jolly_Dogs_Jack_Russell.jpg"
        )
        result = astro.beta.classify(
            img,
            labels=["brown", "black", "spotted", "white", "green", "blue"],
            instructions="the color of the background",
        )
        assert result == "green"

    def test_classify_wet_dog(self):
        img = astro.beta.Image(
            "https://upload.wikimedia.org/wikipedia/commons/d/d5/Retriever_in_water.jpg"
        )

        animal = astro.beta.classify(
            img, labels=["dog", "cat", "bird", "fish", "deer"]
        )
        assert animal == "dog"

        dry_or_wet = astro.beta.classify(
            img, labels=["dry", "wet"], instructions="Is the animal wet?"
        )
        assert dry_or_wet == "wet"


class TestAsync:
    async def test_ny(self):
        img = astro.beta.Image(
            "https://images.unsplash.com/photo-1568515387631-8b650bbcdb90"
        )
        result = await astro.beta.classify_async(img, labels=["urban", "rural"])
        assert result == "urban"


class TestMapping:
    def test_map(self):
        ny = astro.beta.Image(
            "https://images.unsplash.com/photo-1568515387631-8b650bbcdb90"
        )
        dc = astro.beta.Image(
            "https://images.unsplash.com/photo-1617581629397-a72507c3de9e"
        )
        result = astro.beta.classify.map([ny, dc], labels=["urban", "rural"])
        assert isinstance(result, list)
        assert result == ["urban", "urban"]

    async def test_map_async(self):
        ny = astro.beta.Image(
            "https://images.unsplash.com/photo-1568515387631-8b650bbcdb90"
        )
        dc = astro.beta.Image(
            "https://images.unsplash.com/photo-1617581629397-a72507c3de9e"
        )
        result = await astro.beta.classify_async.map(
            [ny, dc], labels=["urban", "rural"]
        )
        assert isinstance(result, list)
        assert result == ["urban", "urban"]
